@@ -5,7 +5,7 @@ from logging.handlers import RotatingFileHandler
 from pathlib import Path
 
 __project__ = "tauk"
-__version__ = "2.0.5"
+__version__ = "2.1.0"
 __author__ = "Nathan Krishnan"
 __url__ = "https://github.com/thetauk/tauk-webdriver-python"
 __platforms__ = "ALL"
@@ -14,7 +14,7 @@ __classifiers__ = [
     "License :: OSI Approved :: MIT License",
     "Operating System :: OS Independent",
 ]
-__requires__ = ["requests", "filelock", "jsonpickle", "tzlocal"]
+__requires__ = ["requests", "filelock", "jsonpickle", "tzlocal", "python-json-logger", "tqdm"]
 
 __extra_requires__ = {
 }
@@ -38,7 +38,6 @@ def _init_logger():
     tauk_logger.addHandler(file_handler)
 
     stream_handler = logging.StreamHandler()
-    # stream_handler.setLevel(logging.ERROR)
     stream_handler.setFormatter(formatter)
     tauk_logger.addHandler(stream_handler)
 
