@@ -8,7 +8,6 @@ import tzlocal
 import tauk
 from tauk.context.test_case import TestCase
 from tauk.context.test_suite import TestSuite
-from tauk.utils import get_filtered_object
 
 logger = logging.getLogger('tauk')
 
@@ -22,11 +21,6 @@ class TestData:
         self.dst = (time.localtime().tm_isdst != 0)
         self._test_suites: typing.List[TestSuite] = []
 
-    def __getstate__(self):
-        state = get_filtered_object(self, include_private=True)
-        # state['test_suites'] = self.test_suites
-        return state
-
     @property
     def test_suites(self):
         return self._test_suites
@@ -44,3 +38,11 @@ class TestData:
             self._test_suites.append(suite)
 
         suite.add_testcase(test_case)
+
+    def delete_test_case(self, filename, test_method_name):
+        suite = self.get_test_suite(filename)
+        if suite is None:
+            logger.warning(f'Failed to delete test case {filename}>{test_method_name}')
+        else:
+            logger.debug(f'Deleting test case {filename}>{test_method_name}')
+            suite.remove_testcase(test_method_name)
