@@ -1,5 +1,6 @@
 import logging
 
+from tauk.config import TaukConfig
 from tauk.listeners.unittest_listener import TaukListener
 from tauk.tauk_webdriver import Tauk
 
@@ -10,7 +11,9 @@ class TaukMultiprocessListener(TaukListener):
 
     def __init__(self, stream, descriptions, verbosity) -> None:
         logger.debug('Initializing Tauk Multiprocess listener')
-        self.multiprocess_run = True
-        self.cleanup_exec_context_on_exit = False
-        Tauk(multi_process_run=self.multiprocess_run, cleanup_exec_context=self.cleanup_exec_context_on_exit)
+
+        tauk_config = TaukConfig(multiprocess_run=True)
+        tauk_config.cleanup_exec_context = False
+        Tauk(tauk_config)
+
         super().__init__(stream, descriptions, verbosity)
